module_component_ptr

Function module_component_ptr 

pub fn module_component_ptr(handle: Element) -> usize
Opaque platform pointer for handle. Phase 7-Φ.H.2.3 — used by whisker-driver’s ElementRef::invoke to call the C bridge without leaking the bridge’s WhiskerElement* type into the runtime crate’s public surface. Returns 0 if no renderer is installed or the renderer doesn’t have a native pointer for handle.